/*
 * Copyright (C) 2003 Andrea Bergia <andreabergia@yahoo.it>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License , or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, write to
 *
 *   The Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111, USA.
 */

#include <qwhatsthis.h>

#include <kiconloader.h>
#include <klocale.h>
#include <kgenericfactory.h>

#include <kdevelop/kdevcore.h>
#include <kdevelop/kdevmainwindow.h>


#include "todolist_widget.h"
#include "todolist_part.h"


typedef KGenericFactory<TodoListPart> TodoListFactory;
K_EXPORT_COMPONENT_FACTORY( libkdevtodolist, TodoListFactory( "kdevtodolist" ) );


TodoListPart::TodoListPart(QObject *parent, const char *name, const QStringList& )
  : KDevPlugin( "KDevPart", "kdevpart", parent, name ? name : "TodoListPart" )
{
  setInstance( TodoListFactory::instance() );
  setXMLFile( "kdevpart_todolist.rc" ); 

  // Create the widget
  m_widget = new TodoListWidget( this );
  m_widget->setIcon( SmallIcon( "filefind" ));
  m_widget->setCaption( i18n( "TODO list output" ));
  
  QWhatsThis::add( m_widget, 
    i18n( "Shows a list of TODO things, by searching in the sources" ) );

  // Embed it
  mainWindow()->embedOutputView( m_widget, "TODO", "TODO things for the project" );
  
  // Now, let's make it do something useful
  connect( core(), SIGNAL( projectOpened() ), m_widget, SLOT( projectOpened() ) );
  connect( core(), SIGNAL( projectClosed() ), m_widget, SLOT( projectClosed() ) );
}


TodoListPart::~TodoListPart()
{
    delete m_widget;
}


#include "todolist_part.moc"
