/*
 * Copyright (C) 2003 Andrea Bergia <andreabergia@yahoo.it>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License , or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, write to
 *
 *   The Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111, USA.
 */

#ifndef TODOLIST_WIDGET_H
#define TODOLIST_WIDGET_H

#include <qwidget.h>
#include <qstring.h>

class KDevProject;
class TodoListPart;
class KListView;
class QListViewItem;

/**
 * This is the panel embedded in Gideon. Searchs in files (better, in URLs)
 * for TODO or @todo tags, reparses a file when saved, and displays the UI.
 *
 * @author Andrea Bergia <andreabergia@yahoo.it>
 * @version 0.1
*/
class TodoListWidget : public QWidget
{
  Q_OBJECT
    
public:
    /**
     * Create the widget
    */
    TodoListWidget(TodoListPart *part);
    
    /**
     * Destructor
    */
    ~TodoListWidget();

public slots:
    /**
     * Called when a project was opened
    */
    void projectOpened();
    
    /**
     * Called when a project was closed
    */
    void projectClosed();

private slots:
    /**
     * Called when the user wants to open a file
    */
    void open( QListViewItem* );
    
    /**
     * Called when the user saves a file, to update the list
    */
    void rescan( const QString& file);
        
private:
    // Scan the project files for todo things
    void scan();
    
    // Scan a single file and add all its item into the todo list
    void scan( const KURL& file );    

    KListView *m_list;
    TodoListPart *m_part;
};


#endif
